@@ -1,6 +1,8 @@
 # -*- mode: python; coding: utf-8 -*-
 
+import os
 import time
+import stat
 
 from hamcrest.core.base_matcher import BaseMatcher
 
@@ -13,7 +15,7 @@ from .const import Status, term, INDENTST
 from .exc import PregoAssertionFailed, PregoAssertionError, log_traceback
 from .item import DeferredItem
 #from .assert_that import assert_that
-from .tools import create_logger, StatusFilter
+from .tools import create_logger, StatusFilter, to_text
 
 
 #-- assertions
@@ -109,14 +111,13 @@ class DeferredAssertion(Assertion):
             assert_that(actual, self.matcher, self._client_reason)
 
         except AssertionError as e:
-            self._reason = u"{0} {1}".format(
-                self.describe_actual(), str(e).decode('utf8'))
+            self._reason = u"{0} {1}".format(self.describe_actual(), to_text(e))
             return False
 
         return True
 
-    def __unicode__(self):
-        return u"assert that %s" % self._reason
+    def __str__(self):
+        return "assert that %s" % self._reason
 
 
 class PollDeferredAssertion(DeferredAssertion):
@@ -179,3 +180,29 @@ class Exists(Matcher):
 
 def exists():
     return Exists()
+
+
+class HasPermissions(Matcher):
+    def __init__(self, expected):
+        self.expected = expected
+
+    def _matches(self, item):
+        if not item.exists():
+            return False
+
+        mode = os.stat(os.path.abspath(item.path)).st_mode
+        print(mode)
+        self.actual = stat.S_IMODE(mode)
+        print(self.actual)
+
+        return (self.actual & self.expected) == self.expected
+
+    def describe_to(self, description):
+        description.append_text('has permissions %s' % self.expected)
+
+    def describe_mismatch(self, item, mismatch_description):
+        mismatch_description.append_text('it has %s' % self.actual)
+
+
+def has_permissions(mask):
+    return HasPermissions(mask)
