@@ -18,10 +18,10 @@ INDENTST = 9 * ' '
 IDENTIFIERS = string.ascii_uppercase + string.ascii_lowercase
 
 config_path = [
-    '.',                           # local
-    '/usr/share/lib/prego',        # debian
-    '/share/lib/prego',            # virtualenv
-    '/usr/local/share/lib/prego']  # pip
+    '.',
+    '/usr/share/lib/prego3',        # debian
+    '/share/lib/prego3',            # virtualenv
+    '/usr/local/share/lib/prego3']  # pip
 
 PREGO_SPECS = os.path.abspath(resolve_path('config.spec', config_path)[0])
 PREGO_CMD_DEFAULTS = os.path.abspath(resolve_path('defaults.config', config_path)[0])
@@ -31,7 +31,7 @@ CWD_CONFIG = os.path.join(os.getcwd(), '.prego')
 
 @memoized
 def term():
-    return blessings.Terminal(force_styling=config.color or None)
+    return blessings.Terminal(force_styling=config.force_color)
 
 
 class Status:
