@@ -1,23 +1,36 @@
 # -*- coding:utf-8; tab-width:4; mode:python -*-
 
+import sys
 import os
 import logging
 
 from . import gvars
-from .const import Status, PREGO_TMP, INDENTST
-from .exc import TestFailed, TestError
+from .const import Status, PREGO_TMP
+from .exc import TestFailed, UserBreak
 from . import config
 from .tools import set_testpath
 
 log = logging.getLogger('prego')
 
 
+if sys.version_info >= (3,9):
+    def thread_alive(t):
+        return t.is_alive()
+else:
+    def thread_alive(t):
+        return t.isAlive()
+
+
 class Runner(object):
+    shutdown = False
+
     def __init__(self, tasks):
         self.tasks = tasks
-        self.keep_running = True
 
     def run(self):
+        if not self.tasks:
+            return
+
         self.run_tasks()
         self.wait_detached()
         self.remove_gen()
@@ -25,9 +38,12 @@ class Runner(object):
 
     def run_tasks(self):
         for t in self.tasks:
-            t.run()
-            if self._stop_condition(t):
-                break
+            try:
+                t.run()
+                if self._stop_condition(t):
+                    break
+            except UserBreak:
+                Runner.shutdown = True
 
     def _stop_condition(self, t):
         if config.keep_going:
@@ -36,7 +52,7 @@ class Runner(object):
         return t.status.is_bad()
 
     def wait_detached(self):
-        log.debug('%s All not detached tasks finished... killing detached',
+        log.debug('%s Some detached tasks did not finish... killing them',
                   Status.indent('-'))
         while 1:
             unfinished = self.get_unfinished_tasks()
@@ -64,8 +80,7 @@ class Runner(object):
                 raise TestFailed(t)
 
     def get_unfinished_tasks(self):
-        return [t for t in self.tasks if t.thread
-                and t.thread.isAlive()]
+        return [t for t in self.tasks if t.thread and thread_alive(t.thread)]
 
 
 def commit(logger=None):
@@ -73,10 +88,10 @@ def commit(logger=None):
     try:
         Runner(gvars.tasks).run()
         result = Status.OK
-    except TestFailed as test_failed:
+    except TestFailed as test_failure:
         result = Status.FAIL
-        # srink trackeback
-        raise test_failed
+        # shrink trackeback
+        raise test_failure
     except:
         result = Status.ERROR
         raise
