@@ -2,6 +2,7 @@
 import time
 
 import hamcrest
+from hamcrest.core.base_matcher import BaseMatcher
 
 from commodity.thread_ import start_new_thread
 from commodity.type_ import checked_type
@@ -12,7 +13,7 @@ from commodity.log import CallerData
 from commodity.path import child_relpath
 
 from .const import Status, INDENTST, term, IDENTIFIERS, PREGO_TMP
-from .exc import (PregoAssertionException, log_traceback)
+from .exc import (PregoAssertionException, log_traceback, UserBreak)
 from .tools import Interpolator
 from .item import File
 from .assertion import (Assertion, DeferredAssertion, PollDeferredAssertion, Delay)
@@ -22,7 +23,11 @@ from . import gvars
 from .assertion import Matcher
 
 from .tools import create_logger, StatusFilter
-#set_logger_default_formatter()
+# set_logger_default_formatter()
+
+
+class MatcherRequiredError(Exception):
+    pass
 
 
 class Task(Printable):
@@ -30,9 +35,9 @@ class Task(Printable):
 
     def __init__(self, desc='', detach=False):
 
-#        print "stdout:", config.stdout
-#        print "stderr:", config.stderr
-#        print "keep-going:", config.keep_going
+        # print "stdout:", config.stdout
+        # print "stderr:", config.stderr
+        # print "keep-going:", config.keep_going
 
         gvars.tasks.append(self)
         self.interpolator = Interpolator()
@@ -132,13 +137,14 @@ class Task(Printable):
 
         except KeyboardInterrupt as e:
             a.status = Status.ERROR
-            a.log_status('user break')
+            a.log_status('USER BREAK')
             a.terminate()
             self.set_reason(Status.ERROR, a)
+            raise UserBreak()
 
         except Exception as e:
             # FIXME: convert e to an Assertion
-#            self.set_reason(Status.ERROR, e)
+            # self.set_reason(Status.ERROR, e)
             log_traceback(self.log, prefix='%s| ' % INDENTST)
 
         finally:
@@ -156,12 +162,14 @@ class Task(Printable):
     def task_start(self):
         self.tinit = time.time()
         detach_advice = ' [DETACHED]' if self.detach else ''
-        msg = u'$status   %s$name   Task starts%s: %s%s' % (
+        msg = '$status   %s$name   Task starts%s: %s%s' % (
             term().bold, detach_advice, self.desc, term().normal)
-        self.log.debug(msg.encode('utf-8', 'ignore'))
+        self.log.debug(msg)
         self.status = Status.UNKNOWN
 
-    def assert_that(self, actual, matcher, reason=''):
+    def assert_that(self, actual, matcher=None, reason=''):
+        if matcher and not isinstance(matcher, BaseMatcher):
+            raise MatcherRequiredError("%s should be a hamcrest Matcher" % str(matcher))
         assertion = DeferredAssertion(self, actual, matcher, reason)
         assertion.caller = CallerData()
         return assertion
@@ -198,7 +206,7 @@ class Task(Printable):
         try:
             return [x for x in self.assertions if isinstance(x, Command)][-1]
         except IndexError:
-            raise IndexError("No command assertion was defined")
+            raise IndexError("No command assertions was defined")
 
     def is_running(self):
         return self.status == Status.UNKNOWN
@@ -246,7 +254,7 @@ class Running(Matcher):
         return cmd.is_running()
 
     def describe_to(self, description):
-        description.append_text('running ')
+        description.append_text('is running ')
 
 
 def running():
