@@ -8,7 +8,8 @@ class pip_tests(TestCase):
     def test_install(self):
         task = Task()
         task.assert_that(Package('python-virtualenv'), installed())
+        task.assert_that(Package('virtualenv'), installed())
         task.command('rm dist/*', expected=None)
-        task.command('python setup.py sdist')
-        task.command('virtualenv --clear venv')
+        task.command('python setup.py sdist', timeout=20)
+        task.command('virtualenv --clear venv', timeout=10)
         task.command('. venv/bin/activate; pip install dist/prego*; echo y | pip uninstall prego; deactivate', timeout=50)
