@@ -1,13 +1,13 @@
 # -*- coding:utf-8; tab-width:4; mode:python -*-
 
-from hamcrest import *
+from hamcrest import is_, contains_string, all_of
 from hamcrest.library.text.stringcontainsinorder import *
 
-from prego import *
+from prego import TestCase, Task, File, exists
 from prego.shell import Variable
 
-nose = 'nosetests -c /dev/null '
-prego_cmd = 'bin/prego-cmd.py -p %s -c /dev/null'
+nose = 'nosetests3 -c /dev/null '
+prego_cmd = 'bin/prego3 -p -c /dev/null %s'
 
 
 class LogTests(TestCase):
@@ -16,24 +16,24 @@ class LogTests(TestCase):
         cmd = task.command(nose + 'examples/examples.py:Test.test_cmd_wrong_true_and_ls',
                            expected=1)
         strings = [
-            "TestFailed: assert that command A.0 returncode to be 0, but was 127",
+            "TestFailed: assert that command A.0 expected returncode 0, but was 127",
             ">> begin captured logging <<",
-            "[FAIL] Task end - elapsed"]
+            "[FAIL]   A   Task end - elapsed:"]
 
         for s in strings:
-            task.assert_that(cmd.stderr.content, s)
+            task.assert_that(cmd.stderr.content, contains_string(s))
 
     def test_show_log_on_fail_command(self):
         task = Task(desc='fail')
         cmd = task.command(nose + 'examples/examples.py:Test.test_cmd_false_true',
                            expected=1)
         strings = [
-            "TestFailed: assert that command A.0 returncode to be 0, but was 1",
+            "TestFailed: assert that command A.0 expected returncode 0, but was 1",
             ">> begin captured logging <<",
-            "[FAIL] Task end - elapsed"]
+            "[FAIL]   A   Task end - elapsed:"]
 
         for s in strings:
-            task.assert_that(cmd.stderr.content, s)
+            task.assert_that(cmd.stderr.content, contains_string(s))
 
 
 class KeepGoingTests(TestCase):
@@ -45,9 +45,9 @@ class KeepGoingTests(TestCase):
 
         strings = [
             "[ ok ]   A.0 Command 'wrong' code (0:127)",
-            "assert that command A.0 returncode to be 0, but was 127",
+            "assert that command A.0 expected returncode 0, but was 127",
             "[ -- ]   A.3 Command 'true'",
-            "[ -- ]   A.5 assert that command A.3 returncode to be 0",
+            "[ -- ]   A.5 assert that command A.3 returncode 0",
             ]
 
         for s in strings:
@@ -61,11 +61,11 @@ class KeepGoingTests(TestCase):
 
         strings = [
             "[ ok ]   A.0 Command 'wrong' code (0:127)",
-            "assert that command A.0 returncode to be 0, but was 127",
+            "assert that command A.0 expected returncode 0, but was 127",
             "[ ok ]   A.3 Command 'true'",
-            "[ ok ]   A.5 assert that command A.3 returncode to be 0",
+            "[ ok ]   A.5 assert that command A.3 returncode 0",
             "[ ok ]   B.0 Command 'ls'",
-            "[ ok ]   B.2 assert that command B.0 returncode to be 0",
+            "[ ok ]   B.2 assert that command B.0 returncode 0",
             ]
 
         for s in strings:
@@ -77,7 +77,7 @@ class GeneratingCommands(TestCase):
     def test_for(self):
         task = Task()
         for i, retcode in [(0, 2), (1, 0), (2, 2)]:
-            task.command('ls -%s' % i, cwd='/tmp', expected=retcode)
+            task.command('ls -%s' % i, cwd='/tmp', expected=retcode, timeout=None)
 
 
 class Assertions(TestCase):
@@ -103,25 +103,25 @@ class OutLoggingTests(TestCase):
         task = Task()
         cmd = task.command(prego_cmd % '-vo examples/command-outs.py:OK.test_ls_stdout_auto')
         task.assert_that(cmd.stderr.content,
-                         contains_string('A.0.out| /initrd.img'))
+                         contains_string('A.0.out| /etc/passwd'))
 
     def test_noauto_log_stdout_when_stdout_flag(self):
         task = Task()
         cmd = task.command(prego_cmd % '-vo examples/command-outs.py:OK.test_ls_stdout')
         task.assert_that(cmd.stderr.content,
-                         contains_string('A.0.out| /initrd.img'))
+                         contains_string('A.0.out| /etc/passwd'))
 
     def test_auto_log_stderr(self):
         task = Task()
         cmd = task.command(prego_cmd % '-ve examples/command-outs.py:OK.test_ls_stderr_auto')
         task.assert_that(cmd.stderr.content,
-                         contains_string('A.0.err| /initrd.img'))
+                         contains_string('A.0.err| /etc/passwd'))
 
     def test_noauto_log_stderr_when_stderr_flag(self):
         task = Task()
         cmd = task.command(prego_cmd % '-ve examples/command-outs.py:OK.test_ls_stderr')
         task.assert_that(cmd.stderr.content,
-                         contains_string('A.0.err| /initrd.img'))
+                         contains_string('A.0.err| /etc/passwd'))
 
     def test_vv_implies_nocapture(self):
         task = Task()
